package CLI::latextable;

use 5.006;
use strict;
use warnings;

=head1 NAME

CLI::latextable - Copy-paste almost any kind of table such as Excel 
worksheet region or SQL output, you get the LaTeX commands to produce 
same table.

=head1 VERSION

Version 0.115

=cut

our $VERSION = '0.115';


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    latextable --help

=head1 LICENSE AND COPYRIGHT

Copyright 2018 "Toshiyuki Shimono".

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see L<http://www.gnu.org/licenses/>.


=cut

1; # End of CLI::latextable
